@@ -1,4 +1,5 @@
 import logging
+from decimal import Decimal
 from collections import defaultdict
 try:
     from collections import OrderedDict
@@ -100,6 +101,10 @@ class Formatter(object):
         else:
             self.keys = keys
 
+        # Keep track of fields/concepts that cause an error to prevent
+        # logging the exception twice
+        self._errors = {}
+
     def __call__(self, values, preferred_formats=None, **context):
         # Create a copy of the preferred formats since each set values may
         # be processed slightly differently (e.g. mixed data type in column)
@@ -150,7 +155,9 @@ class Formatter(object):
                     return output
                 # Remove from the preferred formats list since it failed
                 except Exception:
-                    log.exception('Multi-value formatter error')
+                    if self.concept and self.concept not in self._errors:
+                        self._errors[self.concept] = None
+                        log.exception('Multi-value formatter error')
                     preferred_formats.pop(0)
 
         # The output is independent of the input. Formatters may output more
@@ -161,8 +168,8 @@ class Formatter(object):
         for i, (key, value) in enumerate(values.iteritems()):
             for f in preferred_formats:
                 method = getattr(self, 'to_{0}'.format(f))
+                field = self.fields[key] if self.fields else None
                 try:
-                    field = self.fields[key] if self.fields else None
                     fvalue = method(value, field=field, concept=self.concept,
                         process_multiple=False, **context)
                     if isinstance(fvalue, dict):
@@ -171,7 +178,9 @@ class Formatter(object):
                         output[key] = fvalue
                     break
                 except Exception:
-                    log.exception('Single-value formatter error')
+                    if field and field not in self._errors:
+                        self._errors[field] = None
+                        log.exception('Single-value formatter error')
         return output
 
     def __contains__(self, choice):
@@ -197,20 +206,24 @@ class Formatter(object):
     def to_number(self, value, **context):
         # Attempts to convert a number. Starting with ints and floats
         # Eventually create to_decimal using the decimal library.
-        if type(value) is int or type(value) is float:
+        if isinstance(value, (int, float)):
             return value
+        if isinstance(value, Decimal):
+            return float(str(value))
         if isinstance(value, basestring):
+            if value.isdigit():
+                return int(value)
             try:
-                value = int(value)
+                return float(value)
             except (ValueError, TypeError):
-                value = float(value)
-            return value
+                pass
         raise FormatterException('Cannot convert {0} to number'.format(value))
 
     def to_coded(self, value, **context):
         # Attempts to convert value to its coded representation
-        if 'field' in context:
-            for key, coded in context['field'].coded_values:
+        field = context.get('field')
+        if field:
+            for key, coded in field.coded_values:
                 if key == value:
                     return coded
         raise FormatterException('No coded value for {0}'.format(value))
